@@ -4,10 +4,10 @@ from .embedding import JobEmbedding
 from .searching import JobSearching
 from .scoring import JobScoring
 from .reasoning import JobReasoning
+from .storing import JobStoring
 
 
 class Job(object):
-
     def __init__(self, client):
         self.client = client
         self.parsing = JobParsing(self.client)
@@ -16,3 +16,4 @@ class Job(object):
         self.searching = JobSearching(self.client)
         self.scoring = JobScoring(self.client)
         self.reasoning = JobReasoning(self.client)
+        self.storing = JobStoring(self.client)
