@@ -1,6 +1,6 @@
 import json
 
-from ..utils import validate_provider_keys, validate_limit, validate_page, validate_value
+from ..utils import validate_provider_keys, validate_limit, validate_page, validate_value, validate_response
 
 from ..utils import ORDER_BY_VALUES, SORT_BY_VALUES, STAGE_VALUES
 
@@ -43,4 +43,4 @@ class ProfileSearching():
 
         params = {**query_params, **kwargs}
         response = self.client.get('profiles/searching', params)
-        return response.json()
+        return validate_response(response)
